
.. py:currentmodule:: pythreejs

AxesHelper
====================================================

.. Use autoclass to fill any memebers not manually specified.
   This ensures it picks up any members in overridden classes.

.. autohastraits:: AxesHelper(size=1, )
    :members:
    :undoc-members:


    Inherits :py:class:`~pythreejs.Object3D`.

    Three.js docs: https://threejs.org/docs/#api/helpers/AxesHelper


    .. py:attribute:: size

        .. sourcecode:: python

            CFloat(1, allow_none=False).tag(sync=True)

